==> react-ui-5.0.0.tgz: package/Date.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/ // The require scope
    /******/    var e = {};
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ e.n = n => {
            /******/ var t = n && n.__esModule ? 
            /******/ () => n["default"]
            /******/ : () => n
            /******/;
            e.d(t, {
                a: t
            });
            /******/            return t;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ e.d = (n, t) => {
            /******/ for (var r in t) {
                /******/ if (e.o(t, r) && !e.o(n, r)) {
                    /******/ Object.defineProperty(n, r, {
                        enumerable: true,
                        get: t[r]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ e.o = (e, n) => Object.prototype.hasOwnProperty.call(e, n)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ e.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var n = {};
    // ESM COMPAT FLAG
        e.r(n);
    // EXPORTS
        e.d(n, {
        default: () => /* reexport */ V,
        validateValue: () => /* reexport */ F
    });
    // CONCATENATED MODULE: external "react"
    const t = require("react");
    var r =  e.n(t);
    // CONCATENATED MODULE: external "prop-types"
    const a = require("prop-types");
    var o =  e.n(a);
    // CONCATENATED MODULE: external "lodash/omit"
    const l = require("lodash/omit");
    var u =  e.n(l);
    // CONCATENATED MODULE: external "moment"
    const i = require("moment");
    var c =  e.n(i);
    // CONCATENATED MODULE: external "@splunk/react-ui/Calendar"
    const f = require("@splunk/react-ui/Calendar");
    var s =  e.n(f);
    // CONCATENATED MODULE: external "@splunk/react-ui/Popover"
    const d = require("@splunk/react-ui/Popover");
    var v =  e.n(d);
    // CONCATENATED MODULE: external "@splunk/react-ui/useControlled"
    const p = require("@splunk/react-ui/useControlled");
    var y =  e.n(p);
    // CONCATENATED MODULE: external "@splunk/ui-utils/id"
    const m = require("@splunk/ui-utils/id");
    // CONCATENATED MODULE: external "styled-components"
    const b = require("styled-components");
    var g =  e.n(b);
    // CONCATENATED MODULE: external "@splunk/react-icons/Calendar"
    const h = require("@splunk/react-icons/Calendar");
    var C =  e.n(h);
    // CONCATENATED MODULE: external "@splunk/react-ui/Text"
    const k = require("@splunk/react-ui/Text");
    var S =  e.n(k);
    // CONCATENATED MODULE: ./src/Date/DateStyles.ts
    var O = g()(S()).withConfig({
        displayName: "DateStyles__StyledText",
        componentId: "kacgdc-0"
    })([ "&[data-inline]{width:160px;}" ]);
    var w = g()(C()).withConfig({
        displayName: "DateStyles__StyledCalendarIcon",
        componentId: "kacgdc-1"
    })([ "transform:translateY(1px);" ]);
    // CONCATENATED MODULE: ./src/utils/updateReactRef.ts
    /**
 * Updates a React ref. Callback refs and object refs (from `createRef` and `useRef`) are supported.
 *
 * @param ref - The React callback or object ref. Can be `null` or `undefined`.
 * @param current - The new value of the ref.
 */
    function D(e, n) {
        if (e) {
            if (typeof e === "function") {
                e(n);
            } else {
                // the public signature of this util uses React.Ref<T> to mirror the way React types refs.
                // the intention here is to signal "we will take care of setting 'current', not you".
                e.current = n;
 // eslint-disable-line no-param-reassign
                        }
        }
    }
    // CONCATENATED MODULE: ./src/Date/Date.tsx
    function j() {
        return j = Object.assign ? Object.assign.bind() : function(e) {
            for (var n = 1; n < arguments.length; n++) {
                var t = arguments[n];
                for (var r in t) {
                    ({}).hasOwnProperty.call(t, r) && (e[r] = t[r]);
                }
            }
            return e;
        }, j.apply(null, arguments);
    }
    function I(e, n) {
        return E(e) || A(e, n) || T(e, n) || q();
    }
    function q() {
        throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
    }
    function T(e, n) {
        if (e) {
            if ("string" == typeof e) return x(e, n);
            var t = {}.toString.call(e).slice(8, -1);
            return "Object" === t && e.constructor && (t = e.constructor.name), "Map" === t || "Set" === t ? Array.from(e) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? x(e, n) : void 0;
        }
    }
    function x(e, n) {
        (null == n || n > e.length) && (n = e.length);
        for (var t = 0, r = Array(n); t < n; t++) {
            r[t] = e[t];
        }
        return r;
    }
    function A(e, n) {
        var t = null == e ? null : "undefined" != typeof Symbol && e[Symbol.iterator] || e["@@iterator"];
        if (null != t) {
            var r, a, o, l, u = [], i = !0, c = !1;
            try {
                if (o = (t = t.call(e)).next, 0 === n) {
                    if (Object(t) !== t) return;
                    i = !1;
                } else for (;!(i = (r = o.call(t)).done) && (u.push(r.value), u.length !== n); i = !0) {
                }
            } catch (e) {
                c = !0, a = e;
            } finally {
                try {
                    if (!i && null != t["return"] && (l = t["return"](), Object(l) !== l)) return;
                } finally {
                    if (c) throw a;
                }
            }
            return u;
        }
    }
    function E(e) {
        if (Array.isArray(e)) return e;
    }
    function M(e, n) {
        if (null == e) return {};
        var t, r, a = P(e, n);
        if (Object.getOwnPropertySymbols) {
            var o = Object.getOwnPropertySymbols(e);
            for (r = 0; r < o.length; r++) {
                t = o[r], n.includes(t) || {}.propertyIsEnumerable.call(e, t) && (a[t] = e[t]);
            }
        }
        return a;
    }
    function P(e, n) {
        if (null == e) return {};
        var t = {};
        for (var r in e) {
            if ({}.hasOwnProperty.call(e, r)) {
                if (n.includes(r)) continue;
                t[r] = e[r];
            }
        }
        return t;
    }
    /** @public */
    /** @public */
    /** @public */    var _ = {
        defaultValue: o().string,
        describedBy: o().string,
        disabled: o().bool,
        elementRef: o().oneOfType([ o().func, o().object ]),
        error: o().bool,
        highlightToday: o().bool,
        inline: o().bool,
        inputId: o().string,
        inputOnly: o().bool,
        labelledBy: o().string,
        locale: o().string,
        name: o().string,
        onBlur: o().func,
        onChange: o().func,
        onClick: o().func,
        onFocus: o().func,
        onKeyDown: o().func,
        value: o().string
    };
    /**
 * This static value can be used to convert a moment date to a compatible string
 * to set the `value` prop.
 * ```
 * moment().format(Date.momentFormat);
 * ```
 * @public
 * @name momentFormat
 * @memberOf Date
 * @type string
 */    var R = "YYYY-MM-DD";
    var F = function e(n) {
        if (n === "") {
            return;
        }
        if (!c()(n, R).isValid()) {
            // eslint-disable-next-line no-console
            console.error('Invalid date string value "'.concat(n, '" provided to Moment.'));
        }
    };
    function K(e) {
        var n = e.defaultValue, a = e.disabled, o = e.elementRef, l = e.highlightToday, i = e.inline, d = i === void 0 ? true : i, p = e.inputOnly, b = e.locale, g = b === void 0 ? "en_US" : b, h = e.name, C = e.onChange, k = e.onClick, S = e.onFocus, q = e.onKeyDown, T = e.value, x = M(e, [ "defaultValue", "disabled", "elementRef", "highlightToday", "inline", "inputOnly", "locale", "name", "onChange", "onClick", "onFocus", "onKeyDown", "value" ]);
        // @docs-props-type DatePropsBase
                var A = y()({
            componentName: "Date",
            /* eslint-disable-next-line prefer-rest-params */
            componentProps: arguments[0]
        });
        var E = (0, t.useState)(null), P = I(E, 2), _ = P[0], F = P[1];
        var V = (0, t.useState)(false), Y = I(V, 2), B = Y[0], N = Y[1];
        var U = (0, t.useState)(), z = I(U, 2), $ = z[0], G = z[1];
        var H = (0, t.useState)((function() {
            if (typeof n === "string") {
                return n;
            }
            return c()().locale(g).format(R);
        })), J = I(H, 2), L = J[0], Q = J[1];
        var W = (0, t.useState)(null), X = I(W, 2), Z = X[0], ee = X[1];
        var ne = (0, t.useState)(null), te = I(ne, 2), re = te[0], ae = te[1];
        var oe = (0, t.useRef)(false);
        var le = (0, m.createDOMID)("calendar");
        var ue = (0, t.useMemo)((function() {
            return A ? T : L;
        }), [ A, T, L ]);
        (0, t.useEffect)((function() {
            if (false) {}
        }), [ ue ]);
        (0, t.useEffect)((function() {
            /**
     * If `openWithFocus` and `calendarOpen` are set the user is attempting to navigate to the dropdown, but it's closed.
     * On the first update following the state change set focus to the active day within the calendar.
     */
            if (oe.current && B) {
                oe.current = false;
                (0, f.focusActiveDay)(Z);
            }
        }), [ Z, B ]);
        var ie = (0, t.useMemo)((function() {
            if ($ === undefined) {
                if (ue === undefined || ue === "") {
                    return "";
                }
                return c()(ue, R, g).format("l");
            }
            return $;
        }), [ ue, g, $ ]);
        var ce = (0, t.useCallback)((function(e, n, t) {
            var r = n.value;
            if (t !== "textInput") {
                re === null || re === void 0 ? void 0 : re.focus();
            }
            if (ue !== r) {
                N(false);
                G(undefined);
                Q(A ? undefined : r);
                C === null || C === void 0 ? void 0 : C(e, {
                    value: r,
                    name: h
                });
            } else {
                N(false);
            }
        }), [ ue, re, A, h, C ]);
        var fe = (0, t.useCallback)((function(e) {
            var n = c()($, "l", g);
            if ($ === "") {
                ce(e, {
                    value: ""
                }, "textInput");
            } else if (n.isValid()) {
                ce(e, {
                    value: n.format(K.momentFormat)
                }, "textInput");
            } else {
                N(false);
                G(undefined);
            }
        }), [ ce, g, $ ]);
        var se = (0, t.useCallback)((function(e, n) {
            if (!p) {
                N(true);
            }
            S === null || S === void 0 ? void 0 : S(e, n);
        }), [ p, S ]);
        var de = (0, t.useCallback)((function(e) {
            if (!p && !B) {
                N(true);
            }
            k === null || k === void 0 ? void 0 : k(e);
        }), [ B, p, k ]);
        var ve = (0, t.useCallback)((function(e, n) {
            var t = n.value;
            G(t);
            N(!p);
        }), [ p ]);
        var pe = (0, t.useCallback)((function(e) {
            var n = e.key;
            if (n === "Enter" || n === "Tab") {
                fe(e);
            } else if (!p && n === "ArrowDown") {
                e.preventDefault();
                if (!B) {
                    oe.current = true;
                    N(true);
                } else if (Z) {
                    (0, f.focusActiveDay)(Z);
                }
            } else if (n === "Escape") {
                N(false);
                G(undefined);
                re === null || re === void 0 ? void 0 : re.focus();
            }
            q === null || q === void 0 ? void 0 : q(e);
        }), [ fe, Z, B, re, p, q ]);
        var ye = (0, t.useCallback)((function(e) {
            F(e);
            D(o, e);
        }), [ o ]);
        var me = (0, t.useCallback)((function(e) {
            ae(e);
        }), []);
        var be = (0, t.useCallback)((function(e) {
            ee(e);
        }), []);
        var ge = (0, t.useCallback)((function(e) {
            var n = e.event, t = e.reason;
            if ((t === "clickAway" || t === "escapeKey") && n !== undefined && n.target !== _) {
                fe(n);
                if (t === "escapeKey") {
                    re === null || re === void 0 ? void 0 : re.focus();
                }
            }
        }), [ _, re, fe ]);
        var he = !p &&  r().createElement(w, null);
        var Ce;
        var ke = {};
        if (!p) {
            ke.role = "combobox";
            ke["aria-controls"] = B ? le : undefined;
            ke["aria-expanded"] = a ? false : B;
            ke["aria-haspopup"] = true;
            Ce =  r().createElement(v(), {
                anchor: _,
                id: le,
                open: a ? false : B,
                onRequestClose: ge
            },  r().createElement(s(), {
                elementRef: be,
                highlightToday: l,
                locale: g,
                onChange: ce,
                value: ue === "" ? undefined : ue
            }));
        }
        
        return r().createElement(O, j({
            autoCapitalize: "off",
            autoComplete: "off",
            autoCorrect: "off",
            spellCheck: false,
            "data-test": "date",
            "data-test-value": ue,
            "data-test-popover-id": le,
            disabled: a,
            elementRef: ye,
            inline: d,
            inputRef: me,
            name: h,
            onChange: ve,
            onClick: de,
            onFocus: se,
            onKeyDown: pe,
            value: ie,
            startAdornment: he
        }, ke, u()(x, "multiline", "onSelect", "spellCheck")), Ce);
    }
    K.propTypes = _;
    K.momentFormat = R;
    /* harmony default export */    const V = K;
    // only for styled components using Date
        // CONCATENATED MODULE: ./src/Date/index.ts
    module.exports = n;
    /******/})();

==> react-ui-5.1.0.tgz: package/Date.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/ // The require scope
    /******/    var e = {};
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ e.n = n => {
            /******/ var t = n && n.__esModule ? 
            /******/ () => n["default"]
            /******/ : () => n
            /******/;
            e.d(t, {
                a: t
            });
            /******/            return t;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ e.d = (n, t) => {
            /******/ for (var r in t) {
                /******/ if (e.o(t, r) && !e.o(n, r)) {
                    /******/ Object.defineProperty(n, r, {
                        enumerable: true,
                        get: t[r]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ e.o = (e, n) => Object.prototype.hasOwnProperty.call(e, n)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ e.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var n = {};
    // ESM COMPAT FLAG
        e.r(n);
    // EXPORTS
        e.d(n, {
        default: () => /* reexport */ V,
        validateValue: () => /* reexport */ F
    });
    // CONCATENATED MODULE: external "react"
    const t = require("react");
    var r =  e.n(t);
    // CONCATENATED MODULE: external "lodash/omit"
    const a = require("lodash/omit");
    var l =  e.n(a);
    // CONCATENATED MODULE: external "moment"
    const o = require("moment");
    var u =  e.n(o);
    // CONCATENATED MODULE: external "prop-types"
    const i = require("prop-types");
    var c =  e.n(i);
    // CONCATENATED MODULE: external "@splunk/react-ui/Calendar"
    const f = require("@splunk/react-ui/Calendar");
    var s =  e.n(f);
    // CONCATENATED MODULE: external "@splunk/react-ui/Popover"
    const d = require("@splunk/react-ui/Popover");
    var v =  e.n(d);
    // CONCATENATED MODULE: external "@splunk/react-ui/useControlled"
    const p = require("@splunk/react-ui/useControlled");
    var y =  e.n(p);
    // CONCATENATED MODULE: external "@splunk/ui-utils/id"
    const m = require("@splunk/ui-utils/id");
    // CONCATENATED MODULE: external "styled-components"
    const b = require("styled-components");
    var g =  e.n(b);
    // CONCATENATED MODULE: external "@splunk/react-icons/Calendar"
    const h = require("@splunk/react-icons/Calendar");
    var C =  e.n(h);
    // CONCATENATED MODULE: external "@splunk/react-ui/Text"
    const k = require("@splunk/react-ui/Text");
    var S =  e.n(k);
    // CONCATENATED MODULE: ./src/Date/DateStyles.ts
    var O = g()(S()).withConfig({
        displayName: "DateStyles__StyledText",
        componentId: "kacgdc-0"
    })([ "&[data-inline]{width:160px;}" ]);
    var w = g()(C()).withConfig({
        displayName: "DateStyles__StyledCalendarIcon",
        componentId: "kacgdc-1"
    })([ "transform:translateY(1px);" ]);
    // CONCATENATED MODULE: ./src/utils/updateReactRef.ts
    /**
 * Updates a React ref. Callback refs and object refs (from `createRef` and `useRef`) are supported.
 *
 * @param ref - The React callback or object ref. Can be `null` or `undefined`.
 * @param current - The new value of the ref.
 */
    function D(e, n) {
        if (e) {
            if (typeof e === "function") {
                e(n);
            } else {
                // the public signature of this util uses React.Ref<T> to mirror the way React types refs.
                // the intention here is to signal "we will take care of setting 'current', not you".
                e.current = n;
 // eslint-disable-line no-param-reassign
                        }
        }
    }
    // CONCATENATED MODULE: ./src/Date/Date.tsx
    function j() {
        return j = Object.assign ? Object.assign.bind() : function(e) {
            for (var n = 1; n < arguments.length; n++) {
                var t = arguments[n];
                for (var r in t) {
                    ({}).hasOwnProperty.call(t, r) && (e[r] = t[r]);
                }
            }
            return e;
        }, j.apply(null, arguments);
    }
    function I(e, n) {
        return E(e) || A(e, n) || T(e, n) || q();
    }
    function q() {
        throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
    }
    function T(e, n) {
        if (e) {
            if ("string" == typeof e) return x(e, n);
            var t = {}.toString.call(e).slice(8, -1);
            return "Object" === t && e.constructor && (t = e.constructor.name), "Map" === t || "Set" === t ? Array.from(e) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? x(e, n) : void 0;
        }
    }
    function x(e, n) {
        (null == n || n > e.length) && (n = e.length);
        for (var t = 0, r = Array(n); t < n; t++) {
            r[t] = e[t];
        }
        return r;
    }
    function A(e, n) {
        var t = null == e ? null : "undefined" != typeof Symbol && e[Symbol.iterator] || e["@@iterator"];
        if (null != t) {
            var r, a, l, o, u = [], i = !0, c = !1;
            try {
                if (l = (t = t.call(e)).next, 0 === n) {
                    if (Object(t) !== t) return;
                    i = !1;
                } else for (;!(i = (r = l.call(t)).done) && (u.push(r.value), u.length !== n); i = !0) {
                }
            } catch (e) {
                c = !0, a = e;
            } finally {
                try {
                    if (!i && null != t["return"] && (o = t["return"](), Object(o) !== o)) return;
                } finally {
                    if (c) throw a;
                }
            }
            return u;
        }
    }
    function E(e) {
        if (Array.isArray(e)) return e;
    }
    function M(e, n) {
        if (null == e) return {};
        var t, r, a = P(e, n);
        if (Object.getOwnPropertySymbols) {
            var l = Object.getOwnPropertySymbols(e);
            for (r = 0; r < l.length; r++) {
                t = l[r], n.includes(t) || {}.propertyIsEnumerable.call(e, t) && (a[t] = e[t]);
            }
        }
        return a;
    }
    function P(e, n) {
        if (null == e) return {};
        var t = {};
        for (var r in e) {
            if ({}.hasOwnProperty.call(e, r)) {
                if (n.includes(r)) continue;
                t[r] = e[r];
            }
        }
        return t;
    }
    /** @public */
    /** @public */
    /** @public */    var _ = {
        canClear: c().bool,
        defaultValue: c().string,
        describedBy: c().string,
        disabled: c().bool,
        elementRef: c().oneOfType([ c().func, c().object ]),
        error: c().bool,
        highlightToday: c().bool,
        inline: c().bool,
        inputId: c().string,
        inputOnly: c().bool,
        labelledBy: c().string,
        locale: c().string,
        name: c().string,
        onBlur: c().func,
        onChange: c().func,
        onClick: c().func,
        onFocus: c().func,
        onKeyDown: c().func,
        value: c().string
    };
    /**
 * This static value can be used to convert a moment date to a compatible string
 * to set the `value` prop.
 * ```
 * moment().format(Date.momentFormat);
 * ```
 * @public
 * @name momentFormat
 * @memberOf Date
 * @type string
 */    var R = "YYYY-MM-DD";
    var F = function e(n) {
        if (n === "") {
            return;
        }
        if (!u()(n, R).isValid()) {
            // eslint-disable-next-line no-console
            console.error('Invalid date string value "'.concat(n, '" provided to Moment.'));
        }
    };
    function K(e) {
        var n = e.canClear, a = e.defaultValue, o = e.disabled, i = e.elementRef, c = e.highlightToday, d = e.inline, p = d === void 0 ? true : d, b = e.inputOnly, g = e.locale, h = g === void 0 ? "en_US" : g, C = e.name, k = e.onChange, S = e.onClick, q = e.onFocus, T = e.onKeyDown, x = e.value, A = M(e, [ "canClear", "defaultValue", "disabled", "elementRef", "highlightToday", "inline", "inputOnly", "locale", "name", "onChange", "onClick", "onFocus", "onKeyDown", "value" ]);
        // @docs-props-type DatePropsBase
                var E = y()({
            componentName: "Date",
            /* eslint-disable-next-line prefer-rest-params */
            componentProps: arguments[0]
        });
        var P = (0, t.useState)(null), _ = I(P, 2), F = _[0], V = _[1];
        var Y = (0, t.useState)(false), B = I(Y, 2), N = B[0], U = B[1];
        var z = (0, t.useState)(), $ = I(z, 2), G = $[0], H = $[1];
        var J = (0, t.useState)((function() {
            if (typeof a === "string") {
                return a;
            }
            return u()().locale(h).format(R);
        })), L = I(J, 2), Q = L[0], W = L[1];
        var X = (0, t.useState)(null), Z = I(X, 2), ee = Z[0], ne = Z[1];
        var te = (0, t.useState)(null), re = I(te, 2), ae = re[0], le = re[1];
        var oe = (0, t.useRef)(false);
        var ue = (0, m.createDOMID)("calendar");
        var ie = (0, t.useMemo)((function() {
            return E ? x : Q;
        }), [ E, x, Q ]);
        (0, t.useEffect)((function() {
            if (false) {}
        }), [ ie ]);
        (0, t.useEffect)((function() {
            /**
     * If `openWithFocus` and `calendarOpen` are set the user is attempting to navigate to the dropdown, but it's closed.
     * On the first update following the state change set focus to the active day within the calendar.
     */
            if (oe.current && N) {
                oe.current = false;
                (0, f.focusActiveDay)(ee);
            }
        }), [ ee, N ]);
        var ce = (0, t.useMemo)((function() {
            if (G === undefined) {
                if (ie === undefined || ie === "") {
                    return "";
                }
                return u()(ie, R, h).format("l");
            }
            return G;
        }), [ ie, h, G ]);
        var fe = (0, t.useCallback)((function(e, n, t) {
            var r = n.value;
            if (t !== "textInput") {
                ae === null || ae === void 0 ? void 0 : ae.focus();
            }
            if (ie !== r) {
                U(false);
                H(undefined);
                W(E ? undefined : r);
                k === null || k === void 0 ? void 0 : k(e, {
                    value: r,
                    name: C
                });
            } else {
                U(false);
            }
        }), [ ie, ae, E, C, k ]);
        var se = (0, t.useCallback)((function(e) {
            var n = u()(G, "l", h);
            if (G === "") {
                fe(e, {
                    value: ""
                }, "textInput");
            } else if (n.isValid()) {
                fe(e, {
                    value: n.format(K.momentFormat)
                }, "textInput");
            } else {
                U(false);
                H(undefined);
            }
        }), [ fe, h, G ]);
        var de = (0, t.useCallback)((function(e, n) {
            if (!b) {
                U(true);
            }
            q === null || q === void 0 ? void 0 : q(e, n);
        }), [ b, q ]);
        var ve = (0, t.useCallback)((function(e) {
            if (!b && !N) {
                U(true);
            }
            S === null || S === void 0 ? void 0 : S(e);
        }), [ N, b, S ]);
        var pe = (0, t.useCallback)((function(e, n) {
            var t = n.value;
            H(t);
            U(!b);
        }), [ b ]);
        var ye = (0, t.useCallback)((function(e) {
            var n = e.key;
            if (n === "Enter" || n === "Tab") {
                se(e);
            } else if (!b && n === "ArrowDown") {
                e.preventDefault();
                if (!N) {
                    oe.current = true;
                    U(true);
                } else if (ee) {
                    (0, f.focusActiveDay)(ee);
                }
            } else if (n === "Escape") {
                U(false);
                H(undefined);
                ae === null || ae === void 0 ? void 0 : ae.focus();
            }
            T === null || T === void 0 ? void 0 : T(e);
        }), [ se, ee, N, ae, b, T ]);
        var me = (0, t.useCallback)((function(e) {
            V(e);
            D(i, e);
        }), [ i ]);
        var be = (0, t.useCallback)((function(e) {
            le(e);
        }), []);
        var ge = (0, t.useCallback)((function(e) {
            ne(e);
        }), []);
        var he = (0, t.useCallback)((function(e) {
            var n = e.event, t = e.reason;
            if ((t === "clickAway" || t === "escapeKey") && n !== undefined && n.target !== F) {
                se(n);
                if (t === "escapeKey") {
                    ae === null || ae === void 0 ? void 0 : ae.focus();
                }
            }
        }), [ F, ae, se ]);
        var Ce = !b &&  r().createElement(w, null);
        var ke;
        var Se = {};
        if (!b) {
            Se.role = "combobox";
            Se["aria-controls"] = N ? ue : undefined;
            Se["aria-expanded"] = o ? false : N;
            Se["aria-haspopup"] = true;
            ke =  r().createElement(v(), {
                anchor: F,
                id: ue,
                open: o ? false : N,
                onRequestClose: he
            },  r().createElement(s(), {
                elementRef: ge,
                highlightToday: c,
                locale: h,
                onChange: fe,
                value: ie === "" ? undefined : ie
            }));
        }
        
        return r().createElement(O, j({
            autoCapitalize: "off",
            autoComplete: "off",
            autoCorrect: "off",
            canClear: n,
            "data-test": "date",
            "data-test-value": ie,
            "data-test-popover-id": ue,
            disabled: o,
            elementRef: me,
            inline: p,
            inputRef: be,
            name: C,
            onChange: pe,
            onClick: ve,
            onFocus: de,
            onKeyDown: ye,
            value: ce,
            spellCheck: false,
            startAdornment: Ce
        }, Se, l()(A, "multiline", "onSelect", "spellCheck")), ke);
    }
    K.propTypes = _;
    K.momentFormat = R;
    /* harmony default export */    const V = K;
    // only for styled components using Date
        // CONCATENATED MODULE: ./src/Date/index.ts
    module.exports = n;
    /******/})();
